@@ -16,11 +16,18 @@ run_example <- function(example) {
 }
 
 examples <- if (nzchar(Sys.getenv("TENSORFLOW_TEST_EXAMPLES"))) {
-  c("hello.R",
-    "introduction.R",
-    "mnist/mnist_softmax.R",
-    "mnist/fully_connected_feed.R",
-    "regression/tensorflow_linear_regression.R")
+  examples <-   c("hello.R",
+                  "introduction.R",
+                  "mnist/mnist_softmax.R",
+                  "mnist/fully_connected_feed.R",
+                  "regression/tensorflow_linear_regression.R")
+
+  if (tf_version() >= "2.0") {
+    # disable examples since tf_compat() requires session restart
+    examples <- NULL
+  }
+
+  examples
 }
 
 for (example in examples) {
